# arpes.corrections package

## Submodules

  - [arpes.corrections.background module](arpes.corrections.background)
  - [arpes.corrections.cycle module](arpes.corrections.cycle)
  - [arpes.corrections.fermi\_edge\_corrections
    module](arpes.corrections.fermi_edge_corrections)

## Module contents

**arpes.corrections.build\_reference\_set(df:
pandas.core.frame.DataFrame, mask=None)**

**arpes.corrections.reference\_key(data:
Union\[xarray.core.dataarray.DataArray, xarray.core.dataset.Dataset\])**

**arpes.corrections.apply\_from\_reference\_set(data:
Union\[xarray.core.dataarray.DataArray, xarray.core.dataset.Dataset\],
reference\_set,**kwargs)\*\*

**arpes.corrections.correction\_from\_reference\_set(data:
Union\[xarray.core.dataarray.DataArray, xarray.core.dataset.Dataset\],
reference\_set)**
